@@ -1,16 +1,11 @@
 import os
-import sys
+from collections import OrderedDict
 
 import pyexcel
 from base import PyexcelMultipleSheetBase
 
 from nose.tools import raises
 
-if sys.version_info[0] == 2 and sys.version_info[1] < 7:
-    from ordereddict import OrderedDict
-else:
-    from collections import OrderedDict
-
 
 class TestOdsNxlsMultipleSheets(PyexcelMultipleSheetBase):
     def setUp(self):
