@@ -1,8 +1,8 @@
 import os
 
 from base import PyexcelWriterBase, PyexcelHatWriterBase
-from pyexcel_io import get_data
-from pyexcel_ods.odsw import ODSWriter as Writer
+from pyexcel_ods3 import get_data
+from pyexcel_ods3.odsw import ODSWriter as Writer
 
 
 class TestNativeODSWriter:
@@ -16,7 +16,9 @@ class TestNativeODSWriter:
         writer = Writer(self.testfile, "ods")
         writer.write(self.content)
         writer.close()
-        content = get_data(self.testfile, library="pyexcel-ods")
+        content = get_data(self.testfile)
+        for key in content.keys():
+            content[key] = list(content[key])
         assert content == self.content
 
     def tearDown(self):
